@@ -42,6 +42,10 @@ void onAboutClicked(HildonButton * button, AppData *data) {
 	strcat(infoLabel, "by smurfy (maemo@smurfy.de)\n");
 	strcat(infoLabel, "Version ");
 	strcat(infoLabel, APP_VER);
+	strcat(infoLabel, "\n");
+	strcat(infoLabel, "\n");
+	strcat(infoLabel, "with contributions by\n");
+	strcat(infoLabel, "<i>hcm</i> (segfault patch)");
 
 	hildon_banner_show_information_with_markup(
 			GTK_WIDGET(data->journeyWindow),
@@ -49,6 +53,26 @@ void onAboutClicked(HildonButton * button, AppData *data) {
 			infoLabel);
 }
 
+/**
+ * OnClick Event for a HildonButton
+ * Switchs to Depature Monitor
+ */
+void onDepartureMonitorClicked(HildonButton * button, AppData *data) {
+
+	gtk_widget_hide_all(GTK_WIDGET ( data->journeyWindow ));
+	gtk_widget_show_all(GTK_WIDGET ( data->departureWindow ));
+}
+
+/**
+ * OnClick Event for a HildonButton
+ * Switchs to Journey Planner
+ */
+void onJourneyPlannerClicked(HildonButton * button, AppData *data) {
+
+	gtk_widget_hide_all(GTK_WIDGET ( data->departureWindow ));
+	gtk_widget_show_all(GTK_WIDGET ( data->journeyWindow ));
+}
+
 /**
  * OnClick Event for a HildonButton
  * Handles display of station selector
@@ -686,7 +710,15 @@ void initStationSelectorDialog(AppData *data) {
 	gtk_widget_show_all(GTK_WIDGET (data->currentDialog));
 	gtk_dialog_run(GTK_DIALOG (data->currentDialog));
 }
+/**
+ * Init Departure Monitor Gui Window
+ */
+void initDepartureMonitorGui(AppData *data) {
 
+	/* Create HildonWindow and set it to HildonProgram */
+	data->departureWindow = HILDON_WINDOW(hildon_stackable_window_new());
+
+}
 /**
  * Init Journey Planer Gui Window
  */
@@ -694,15 +726,6 @@ void initJourneyPlanerGui(AppData *data) {
 
 	/* Create HildonWindow and set it to HildonProgram */
 	data->journeyWindow = HILDON_WINDOW(hildon_stackable_window_new());
-	hildon_program_add_window(data->program, data->journeyWindow);
-
-	/* Quit program when window is closed. */
-	g_signal_connect (G_OBJECT (data->journeyWindow), "delete_event",
-			G_CALLBACK (gtk_main_quit), NULL);
-
-	/* Quit program when window is otherwise destroyed. */
-	g_signal_connect (G_OBJECT (data->journeyWindow), "destroy",
-			G_CALLBACK (gtk_main_quit), NULL);
 
 	/* create vertical container to stack the other containers vertically and add to main view */
 	data->verticalContainer = gtk_vbox_new(FALSE, 4);
@@ -806,6 +829,11 @@ void initJourneyPlanerGui(AppData *data) {
 	gtk_box_pack_start(GTK_BOX (data->verticalContainer), data->searchButton,
 			TRUE, TRUE, 0);
 
+}
+
+/** Creates the Main Menu and appends to the main windows */
+void initMainWindowsMenu(AppData *data) {
+
 	/* Create menu */
 	GtkWidget * button;
 	HildonAppMenu *menu = HILDON_APP_MENU (hildon_app_menu_new ());
@@ -820,22 +848,32 @@ void initJourneyPlanerGui(AppData *data) {
 	hildon_app_menu_append(menu, GTK_BUTTON (button));
 
 	/* Create filters */
-	/*
+
 	button = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO, NULL);
 	gtk_button_set_label(GTK_BUTTON (button), _("Journey Planner"));
 	hildon_app_menu_add_filter(menu, GTK_BUTTON (button));
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON (button), FALSE);
 
+	/* Attach callback to clicked signal */
+	g_signal_connect_after (button, "clicked", G_CALLBACK (onJourneyPlannerClicked), data);
+
+	/*
 	button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO, GTK_RADIO_BUTTON(button));
 	gtk_button_set_label(GTK_BUTTON (button), _("Departures"));
 	hildon_app_menu_add_filter(menu, GTK_BUTTON (button));
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON (button), FALSE);
 	*/
 
+	/* Attach callback to clicked signal */
+	/*
+	 * g_signal_connect_after (button, "clicked", G_CALLBACK (onDepartureMonitorClicked), data);
+ 	 */
+
 	gtk_widget_show_all(GTK_WIDGET (menu));
 
-	/* Attach menu to the window */
+	/* Attach menu to the windows */
 	hildon_window_set_app_menu (HILDON_WINDOW (data->journeyWindow), menu);
+	hildon_window_set_app_menu (HILDON_WINDOW (data->departureWindow), menu);
 }
 
 /**
@@ -859,12 +897,18 @@ void initApplication(AppData *data) {
 	data->program = HILDON_PROGRAM(hildon_program_get_instance());
 	g_set_application_name(_("Fahrplan"));
 
-	/* Init Main window */
+	/* Init Journy Planer window */
 	initJourneyPlanerGui(data);
 
+	/* Init Departure Monitor Planer window */
+	initDepartureMonitorGui(data);
+
 	/* Init Test Elements */
 	/* initTestElements(data); */
 
-	/* Show Main Window */
+	/* Create Main Menu */
+	initMainWindowsMenu(data);
+
+	/* Show Default Window Window */
 	gtk_widget_show_all(GTK_WIDGET ( data->journeyWindow ));
 }
