@@ -325,7 +325,7 @@ ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation,
 		char *newUrl;
 
 		char *urlFrom =	strstr(result,
-				"<form action=\"http://mobile.bahn.de/bin/mobil/query.exe/dox?");
+				"<form action=\"//mobile.bahn.de/bin/mobil/query.exe/dox?");
 
 		if (urlFrom) {
 
@@ -356,7 +356,7 @@ ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation,
 		if (newUrl) {
 
 			gchar * postData = g_strdup_printf("REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0K=%s&REQ0JourneyStopsS0ID=&REQ0JourneyStopsZ0A=1&REQ0JourneyStopsZ0K=%s&REQ0JourneyStopsZ0ID=&REQ0JourneyDate=%d.%d.%d&REQ0JourneyTime=%d:%d&REQ0HafasSearchForw=%d&existOptimizePrice=1&REQ0HafasOptimize1=0%3A1&existProductNahverkehr=yes&REQ0Tariff_TravellerAge.1=35&start=Suchen&REQ0Tariff_Class=2&REQ0Tariff_TravellerReductionClass.1=0", fromStation, toStation, day, month , year, hour, minutes, options);
-			gchar * url      = g_strdup_printf(newUrl);
+			gchar * url      = g_strdup_printf("http:%s",newUrl);
 			gchar * result   = performCurlRequest(url, postData);
 
 			if (!result) {
@@ -785,8 +785,8 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 
 									testStr[strlen(testStr) - strlen(testStrLater)] = '\0';
 
-									resultInfo->headerEarlierUrl = g_strdup_printf("%se=2", testStr);
-									resultInfo->headerLaterUrl = g_strdup_printf("%se=1", testStr);
+									resultInfo->headerEarlierUrl = g_strdup_printf("http:%se=2", testStr);
+									resultInfo->headerLaterUrl = g_strdup_printf("http:%se=1", testStr);
 								}
 							}
 						}
@@ -879,7 +879,7 @@ GArray * mobilebahnde_getResultValues(xmlNode * a_node) {
 
 								if (!strcmp(cur_attribute->name, "href")) {
 
-									resultItem->detailsUrl = g_strdup_printf(cur_attribute->children->content);
+									resultItem->detailsUrl = g_strdup_printf("http:%s", cur_attribute->children->content);
 								}
 							}
 
